body {
  font-family: monospace, monospace;
}

.event-content {
  height: 100%;
  width: 100%;
  padding: 0;
  padding-top: 3px;
  padding-bottom: 3px;
  padding-left: 5px;
  text-align: left;
}

.disable-dbl-tap-zoom {
  touch-action: manipulation;
}
